# NFT Mint Wallet Analysis 

To make NFT space better, this analysis helps people to see who is behind the mint.

We analyze the mint addresses and figure out their relationship.

The result will show us if NFT are allocated to specific group or be controlled by specific people.

Here is the result of mint analysis.

https://www.notion.so/079e06017f094cee87e207b2e3fb57b9?v=01d5c78c8c944f4c8f7bbaa4bc9c4363

![image](https://user-images.githubusercontent.com/88714881/224921094-b3d72e9c-16fb-4e05-953a-da8d23a36796.png)


1️⃣ **Participated Rate**

<aside>
💡 Participated Wallets / Total Supply

(Higer the rate, more people join the Project)

</aside>

The purpose of this index is to find whether project let as many as people join.

**Notice**
We are not able to consider Airdrop or preserve spots for pre-holder now.

2️⃣ **Greed Rate**

<aside>
💡 1- Groups / Participated Wallets

(Higer the rate, more repetitive people in the Project)

</aside>

It means that the strategy of their selling can easily benefit some people or let repetitive people to get WL or buy. 

**Notice**
We are not able to consider Airdrop or preserve spots for pre-holder now.

3️⃣ **Allocation Rate**

<aside>
💡 (Group’s mint ≥ Avg Mint) / Groups

(Higher the rate, more average NFT allocation)

</aside>

We can find how NFT are allocated to grups, then we can have an overall rate to see the allcoation rate. 

**Notice**
Avg Mint is the rounding of (Total Supply / Groups) by default. It may not well reflect the situation for small supply or 1mint / address. We will adjust it in the future.
